[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# IRN Configuration client library for Python

[![API Version](https://img.shields.io/badge/api-v1.0.0-blue)](https://developer.factset.com/api-catalog/irn-configuration-api#apiDocumentation)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.IRNConfiguration)](https://pypi.org/project/fds.sdk.IRNConfiguration/)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

Allows users to extract, create, update and configure IRN data.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- SDK version: 1.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.IRNConfiguration==1.1.0
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.IRNConfiguration==1.1.0
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.IRNConfiguration
from fds.sdk.IRNConfiguration.api import contacts___custom_fields_api
from fds.sdk.IRNConfiguration.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.IRNConfiguration.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.IRNConfiguration.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.IRNConfiguration.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = contacts___custom_fields_api.ContactsCustomFieldsApi(api_client)
    contact_custom_field_save_dto = ContactCustomFieldSaveDto(
        code="code_example",
        name="name_example",
        type=ContactCustomFieldType(0),
        is_hidden=False,
        is_mandatory=False,
        field_formula=ContactCustomFieldFormulaDto(
            formula="formula_example",
            is_screening=False,
            symbol="symbol_example",
        ),
        contact_custom_field_options=[
            ContactCustomFieldOptionSaveDto(
                name="name_example",
            ),
        ],
    ) # ContactCustomFieldSaveDto | ContactCustomFieldSaveDto object to save (optional)

    try:
        # Create a contact custom field
        # example passing only required values which don't have defaults set
        # and optional values
        api_response = api_instance.create_contact_custom_field(contact_custom_field_save_dto=contact_custom_field_save_dto)

        pprint(api_response)
    except fds.sdk.IRNConfiguration.ApiException as e:
        print("Exception when calling ContactsCustomFieldsApi->create_contact_custom_field: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Create a contact custom field
    #     api_response, http_status_code, response_headers = api_instance.create_contact_custom_field_with_http_info(contact_custom_field_save_dto=contact_custom_field_save_dto)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.IRNConfiguration.ApiException as e:
    #     print("Exception when calling ContactsCustomFieldsApi->create_contact_custom_field: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Create a contact custom field
    #     async_result = api_instance.create_contact_custom_field_async(contact_custom_field_save_dto=contact_custom_field_save_dto)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.IRNConfiguration.ApiException as e:
    #     print("Exception when calling ContactsCustomFieldsApi->create_contact_custom_field: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Create a contact custom field
    #     async_result = api_instance.create_contact_custom_field_with_http_info_async(contact_custom_field_save_dto=contact_custom_field_save_dto)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.IRNConfiguration.ApiException as e:
    #     print("Exception when calling ContactsCustomFieldsApi->create_contact_custom_field: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.IRNConfiguration

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.IRNConfiguration.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.IRNConfiguration

configuration = fds.sdk.IRNConfiguration.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.IRNConfiguration

configuration = fds.sdk.IRNConfiguration.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.IRNConfiguration

configuration = fds.sdk.IRNConfiguration.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/research/irn/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ContactsCustomFieldsApi* | [**create_contact_custom_field**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsCustomFieldsApi.md#create_contact_custom_field) | **POST** /contact-custom-fields | Create a contact custom field
*ContactsCustomFieldsApi* | [**delete_contact_custom_field**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsCustomFieldsApi.md#delete_contact_custom_field) | **DELETE** /contact-custom-fields/{contactCustomFieldId} | Delete a contact custom field
*ContactsCustomFieldsApi* | [**get_contact_custom_field**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsCustomFieldsApi.md#get_contact_custom_field) | **GET** /contact-custom-fields/{contactCustomFieldId} | Get a specific Contact custom field&#39;s details
*ContactsCustomFieldsApi* | [**get_contact_custom_fields**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsCustomFieldsApi.md#get_contact_custom_fields) | **GET** /contact-custom-fields | Get all the contact custom fields
*ContactsCustomFieldsApi* | [**patch_contact_custom_field**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsCustomFieldsApi.md#patch_contact_custom_field) | **PATCH** /contact-custom-fields/{contactCustomFieldId} | Edit a contact custom field
*ContactsPhoneNumberTypesApi* | [**create_phone_number_type**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsPhoneNumberTypesApi.md#create_phone_number_type) | **POST** /phone-number-types | Create a phone type
*ContactsPhoneNumberTypesApi* | [**delete_phone_number_type**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsPhoneNumberTypesApi.md#delete_phone_number_type) | **DELETE** /phone-number-types/{phoneNumberTypeId} | Delete a phone type
*ContactsPhoneNumberTypesApi* | [**get_phone_number_types**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsPhoneNumberTypesApi.md#get_phone_number_types) | **GET** /phone-number-types | Get list of the phone types configured in your group
*ContactsPhoneNumberTypesApi* | [**update_phone_number_type**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsPhoneNumberTypesApi.md#update_phone_number_type) | **PUT** /phone-number-types/{phoneNumberTypeId} | Edit a phone type
*ContactsRelationshipCategoryApi* | [**create_relationship_category**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsRelationshipCategoryApi.md#create_relationship_category) | **POST** /relationship-categories | Create a relationship category
*ContactsRelationshipCategoryApi* | [**delete_relationship_category**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsRelationshipCategoryApi.md#delete_relationship_category) | **DELETE** /relationship-categories/{relationshipCategoryId} | Delete a relationship category
*ContactsRelationshipCategoryApi* | [**edit_relationship_category**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsRelationshipCategoryApi.md#edit_relationship_category) | **PUT** /relationship-categories/{relationshipCategoryId} | Edit a relationship category
*ContactsRelationshipCategoryApi* | [**get_relationship_categories**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsRelationshipCategoryApi.md#get_relationship_categories) | **GET** /relationship-categories | Get list of the relationship categories configured in your group
*ContactsRelationshipCategoryApi* | [**update_relationship_category_order**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsRelationshipCategoryApi.md#update_relationship_category_order) | **POST** /relationship-categories/reorder | Reorder relationship categories
*ContactsRelationshipsApi* | [**create_contact_relationship_type**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsRelationshipsApi.md#create_contact_relationship_type) | **POST** /relationships | Create a relationship type
*ContactsRelationshipsApi* | [**delete_relationship**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsRelationshipsApi.md#delete_relationship) | **DELETE** /relationships/{relationshipId} | Delete a relationship type
*ContactsRelationshipsApi* | [**edit_relationship**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsRelationshipsApi.md#edit_relationship) | **PUT** /relationships/{relationshipId} | Edit a relationship type
*ContactsRelationshipsApi* | [**get_relationships**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsRelationshipsApi.md#get_relationships) | **GET** /relationships | Get list of the relationships configured in your group
*ContactsRolesApi* | [**create_contact_role**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsRolesApi.md#create_contact_role) | **POST** /contact-roles | Create contact roles
*ContactsRolesApi* | [**delete_contact_role**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsRolesApi.md#delete_contact_role) | **DELETE** /contact-roles/{contactRoleId} | Delete a contact role
*ContactsRolesApi* | [**get_contact_roles**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsRolesApi.md#get_contact_roles) | **GET** /contact-roles | Get list of the contact roles configured in your group
*ContactsRolesApi* | [**update_contact_role**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsRolesApi.md#update_contact_role) | **PUT** /contact-roles/{contactRoleId} | Edit a contact role
*ContactsTypesApi* | [**create_contact_type**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsTypesApi.md#create_contact_type) | **POST** /contact-types | Create contact types
*ContactsTypesApi* | [**delete_contact_type**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsTypesApi.md#delete_contact_type) | **DELETE** /contact-types/{contactTypeId} | Delete a contact type
*ContactsTypesApi* | [**get_contact_types**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsTypesApi.md#get_contact_types) | **GET** /contact-types | Get list of the contact types configured in your group
*ContactsTypesApi* | [**update_contact_type**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactsTypesApi.md#update_contact_type) | **PUT** /contact-types/{contactTypeId} | Edit a contact type
*CustomSymbolsCustomFieldsApi* | [**create_custom_symbol_custom_field**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsCustomFieldsApi.md#create_custom_symbol_custom_field) | **POST** /custom-symbol-custom-fields | Create a Custom symbol custom field
*CustomSymbolsCustomFieldsApi* | [**delete_custom_symbol_custom_field**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsCustomFieldsApi.md#delete_custom_symbol_custom_field) | **DELETE** /custom-symbol-custom-fields/{customSymbolCustomFieldId} | Delete a Custom symbol custom field
*CustomSymbolsCustomFieldsApi* | [**get_custom_symbol_custom_field**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsCustomFieldsApi.md#get_custom_symbol_custom_field) | **GET** /custom-symbol-custom-fields/{customSymbolCustomFieldId} | Get a specific Custom symbol custom field&#39;s details
*CustomSymbolsCustomFieldsApi* | [**get_custom_symbol_custom_fields**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsCustomFieldsApi.md#get_custom_symbol_custom_fields) | **GET** /custom-symbol-custom-fields | Get all the Custom symbol custom fields
*CustomSymbolsCustomFieldsApi* | [**patch_custom_symbol_custom_field**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsCustomFieldsApi.md#patch_custom_symbol_custom_field) | **PATCH** /custom-symbol-custom-fields/{customSymbolCustomFieldId} | Edit a Custom symbol custom field
*CustomSymbolsRelationshipsApi* | [**create_symbol_relationship_type**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsRelationshipsApi.md#create_symbol_relationship_type) | **POST** /symbols-relationships | Create a symbol relationship
*CustomSymbolsRelationshipsApi* | [**delete_symbols_relationship**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsRelationshipsApi.md#delete_symbols_relationship) | **DELETE** /symbols-relationships/{symbolsRelationshipId} | Delete a symbol relationship
*CustomSymbolsRelationshipsApi* | [**edit_symbols_relationship**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsRelationshipsApi.md#edit_symbols_relationship) | **PUT** /symbols-relationships/{symbolsRelationshipId} | Edit a symbol relationship
*CustomSymbolsRelationshipsApi* | [**get_symbols_relationships**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsRelationshipsApi.md#get_symbols_relationships) | **GET** /symbols-relationships | Get all the Symbols Relationships
*CustomSymbolsTypesApi* | [**create_custom_symbol_type**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsTypesApi.md#create_custom_symbol_type) | **POST** /custom-symbol-types | Create a Custom symbol type
*CustomSymbolsTypesApi* | [**delete_custom_symbol_type_async**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsTypesApi.md#delete_custom_symbol_type_async) | **DELETE** /custom-symbol-types/{customSymbolTypeId} | Delete a Custom symbol type
*CustomSymbolsTypesApi* | [**get_custom_symbol_type**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsTypesApi.md#get_custom_symbol_type) | **GET** /custom-symbol-types/{customSymbolTypeId} | Get a specific Custom symbol type&#39;s details
*CustomSymbolsTypesApi* | [**get_custom_symbol_types**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsTypesApi.md#get_custom_symbol_types) | **GET** /custom-symbol-types | Get all the custom symbol types
*CustomSymbolsTypesApi* | [**get_symbol_custom_fields_for_custom_symbol_type**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsTypesApi.md#get_symbol_custom_fields_for_custom_symbol_type) | **GET** /custom-symbol-types/{customSymbolTypeId}/custom-fields | Get Custom fields for Custom Symbol type
*CustomSymbolsTypesApi* | [**update_custom_symbol_type**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsTypesApi.md#update_custom_symbol_type) | **PUT** /custom-symbol-types/{customSymbolTypeId} | Edit a Custom symbol type
*CustomSymbolsTypesApi* | [**update_custom_symbol_type_order**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolsTypesApi.md#update_custom_symbol_type_order) | **POST** /custom-symbol-types/reorder | Reorder custom symbol types
*NotesConfigurationApi* | [**get_assigned_fact_set_users**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NotesConfigurationApi.md#get_assigned_fact_set_users) | **GET** /users | Get all assigned FactSet users
*NotesConfigurationApi* | [**get_authors**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NotesConfigurationApi.md#get_authors) | **GET** /authors | Get all Authors
*NotesConfigurationApi* | [**get_clients_sales_representative**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NotesConfigurationApi.md#get_clients_sales_representative) | **GET** /group/client-sales-representative | Get Client Sales Representative
*NotesConfigurationApi* | [**get_custom_fields**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NotesConfigurationApi.md#get_custom_fields) | **GET** /custom-fields | Get all Custom Fields
*NotesConfigurationApi* | [**get_group**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NotesConfigurationApi.md#get_group) | **GET** /group | Get Group details
*NotesConfigurationApi* | [**get_recommendations**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NotesConfigurationApi.md#get_recommendations) | **GET** /recommendations | Get all Recommendations
*NotesConfigurationApi* | [**get_sentiments**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NotesConfigurationApi.md#get_sentiments) | **GET** /sentiments | Get all Sentiments
*NotesConfigurationApi* | [**get_subject**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NotesConfigurationApi.md#get_subject) | **GET** /subjects/{subjectId} | Get Subject details for the given Id provided
*NotesConfigurationApi* | [**get_subjects**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NotesConfigurationApi.md#get_subjects) | **GET** /subjects | Get all Subjects
*NotesConfigurationApi* | [**get_team**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NotesConfigurationApi.md#get_team) | **GET** /teams/{teamId} | Get Team details for the given Id provided
*NotesConfigurationApi* | [**get_teams**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NotesConfigurationApi.md#get_teams) | **GET** /teams | Get all Teams


## Documentation For Models

 - [ApprovalLevelConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ApprovalLevelConfigDto.md)
 - [ApprovalProcessConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ApprovalProcessConfigDto.md)
 - [AuthorConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/AuthorConfigDto.md)
 - [ClientSalesRepresentativeDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ClientSalesRepresentativeDto.md)
 - [CommentaryConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CommentaryConfigDto.md)
 - [ContactCustomFieldDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactCustomFieldDto.md)
 - [ContactCustomFieldFormulaDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactCustomFieldFormulaDto.md)
 - [ContactCustomFieldOptionDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactCustomFieldOptionDto.md)
 - [ContactCustomFieldOptionSaveDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactCustomFieldOptionSaveDto.md)
 - [ContactCustomFieldSaveDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactCustomFieldSaveDto.md)
 - [ContactCustomFieldType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactCustomFieldType.md)
 - [ContactRoleDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactRoleDto.md)
 - [ContactTypeDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ContactTypeDto.md)
 - [CreateCustomSymbolCustomFieldDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CreateCustomSymbolCustomFieldDto.md)
 - [CustomFieldConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomFieldConfigDto.md)
 - [CustomFieldTeamConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomFieldTeamConfigDto.md)
 - [CustomFieldUserTeamLookupFilterType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomFieldUserTeamLookupFilterType.md)
 - [CustomSymbolCustomFieldConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolCustomFieldConfigDto.md)
 - [CustomSymbolCustomFieldFormulaConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolCustomFieldFormulaConfigDto.md)
 - [CustomSymbolSubTypeDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolSubTypeDto.md)
 - [CustomSymbolTypeDetailDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolTypeDetailDto.md)
 - [CustomSymbolTypeDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolTypeDto.md)
 - [CustomSymbolTypeSummaryDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/CustomSymbolTypeSummaryDto.md)
 - [DateSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/DateSettingsDto.md)
 - [EntityType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/EntityType.md)
 - [ExtendedTextConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ExtendedTextConfigDto.md)
 - [FormulaConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/FormulaConfigDto.md)
 - [GroupConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/GroupConfigDto.md)
 - [GroupFieldsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/GroupFieldsDto.md)
 - [HeadlineFormatConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/HeadlineFormatConfigDto.md)
 - [IdentifierSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/IdentifierSettingsDto.md)
 - [IntegerConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/IntegerConfigDto.md)
 - [LinkSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/LinkSettingsDto.md)
 - [NewItemDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NewItemDto.md)
 - [NoteSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NoteSettingsDto.md)
 - [NumericConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/NumericConfigDto.md)
 - [Operation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/Operation.md)
 - [OperationType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/OperationType.md)
 - [OptionsConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/OptionsConfigDto.md)
 - [OrganizerSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/OrganizerSettingsDto.md)
 - [PhoneNumberTypeDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/PhoneNumberTypeDto.md)
 - [ProblemDetails](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ProblemDetails.md)
 - [RatingConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/RatingConfigDto.md)
 - [RecommendationConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/RecommendationConfigDto.md)
 - [RecommendationSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/RecommendationSettingsDto.md)
 - [RelatedContactsSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/RelatedContactsSettingsDto.md)
 - [RelatedResearchSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/RelatedResearchSettingsDto.md)
 - [RelatedSymbolsSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/RelatedSymbolsSettingsDto.md)
 - [RelationshipCategoryDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/RelationshipCategoryDto.md)
 - [RelationshipCategoryListDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/RelationshipCategoryListDto.md)
 - [RelationshipCategorySaveDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/RelationshipCategorySaveDto.md)
 - [RelationshipDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/RelationshipDto.md)
 - [RelationshipSaveDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/RelationshipSaveDto.md)
 - [RelationshipType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/RelationshipType.md)
 - [ReorderCustomSymbolTypeDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/ReorderCustomSymbolTypeDto.md)
 - [SaveCustomSymbolTypeDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/SaveCustomSymbolTypeDto.md)
 - [SentimentConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/SentimentConfigDto.md)
 - [SentimentSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/SentimentSettingsDto.md)
 - [SourceSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/SourceSettingsDto.md)
 - [SubjectConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/SubjectConfigDto.md)
 - [SubjectSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/SubjectSettingsDto.md)
 - [SubjectSummaryDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/SubjectSummaryDto.md)
 - [SymbolsRelationShipSaveDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/SymbolsRelationShipSaveDto.md)
 - [SymbolsRelationshipDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/SymbolsRelationshipDto.md)
 - [TeamConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/TeamConfigDto.md)
 - [TeamSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/TeamSettingsDto.md)
 - [TeamSummaryDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/TeamSummaryDto.md)
 - [TitleSettingsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/TitleSettingsDto.md)
 - [UpdateCustomSymbolTypeDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/UpdateCustomSymbolTypeDto.md)
 - [UserConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/UserConfigDto.md)
 - [UserTeamConfigDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNConfiguration/v1/docs/UserTeamConfigDto.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.IRNConfiguration.apis and fds.sdk.IRNConfiguration.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.IRNConfiguration.api.default_api import DefaultApi`
- `from fds.sdk.IRNConfiguration.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.IRNConfiguration
from fds.sdk.IRNConfiguration.apis import *
from fds.sdk.IRNConfiguration.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

